@@ -5,6 +5,7 @@
  * See top-level LICENSE file for more information
  */
 
+import 'cypress-hmr-restarter';
 import '@cypress/code-coverage/support';
 
 import {httpGetJson} from '../utils';
@@ -19,7 +20,7 @@ Cypress.Commands.add('xhrShouldBeCalled', (alias, timesCalled) => {
   expect(Object.keys(aliasRoute.requests || {})).to.have.length(timesCalled);
 });
 
-Cypress.Commands.add('adminLogin', () => {
+function loginUser(username, password) {
   const url = '/admin/login/';
   return cy.request({
     url: url,
@@ -33,8 +34,8 @@ Cypress.Commands.add('adminLogin', () => {
         form: true,
         followRedirect: false,
         body: {
-          username: 'admin',
-          password: 'admin',
+          username: username,
+          password: password,
           csrfmiddlewaretoken: token
         }
       }).then(() => {
@@ -43,6 +44,18 @@ Cypress.Commands.add('adminLogin', () => {
       });
     });
   });
+}
+
+Cypress.Commands.add('adminLogin', () => {
+  return loginUser('admin', 'admin');
+});
+
+Cypress.Commands.add('userLogin', () => {
+  return loginUser('user', 'user');
+});
+
+Cypress.Commands.add('ambassadorLogin', () => {
+  return loginUser('ambassador', 'ambassador');
 });
 
 before(function() {
@@ -108,7 +121,7 @@ before(function() {
   cy.visit('/').window().then(async win => {
     this.Urls = win.Urls;
 
-    for (let origin of this.origin) {
+    for (const origin of this.origin) {
 
       const metadata = await getMetadataForOrigin(origin.url);
       const directoryApiUrl = this.Urls.api_1_directory(metadata.directory);
@@ -117,7 +130,7 @@ before(function() {
       origin.revisions.push(metadata.revision);
       origin.snapshot = metadata.snapshot;
 
-      for (let content of origin.content) {
+      for (const content of origin.content) {
 
         const contentPathApiUrl = this.Urls.api_1_directory(origin.rootDirectory, content.path);
         const contentMetaData = await httpGetJson(contentPathApiUrl);
