@@ -8,38 +8,58 @@ Website: https://yaml.org
 Category: common, config
 */
 function yaml(hljs) {
-  var LITERALS = 'true false yes no null';
+  const LITERALS = 'true false yes no null';
 
   // YAML spec allows non-reserved URI characters in tags.
-  var URI_CHARACTERS = '[\\w#;/?:@&=+$,.~*\\\'()[\\]]+';
+  const URI_CHARACTERS = '[\\w#;/?:@&=+$,.~*\'()[\\]]+';
 
   // Define keys as starting with a word character
   // ...containing word chars, spaces, colons, forward-slashes, hyphens and periods
   // ...and ending with a colon followed immediately by a space, tab or newline.
   // The YAML spec allows for much more than this, but this covers most use-cases.
-  var KEY = {
+  const KEY = {
     className: 'attr',
     variants: [
-      { begin: '\\w[\\w :\\/.-]*:(?=[ \t]|$)' },
-      { begin: '"\\w[\\w :\\/.-]*":(?=[ \t]|$)' }, // double quoted keys
-      { begin: '\'\\w[\\w :\\/.-]*\':(?=[ \t]|$)' } // single quoted keys
+      {
+        begin: '\\w[\\w :\\/.-]*:(?=[ \t]|$)'
+      },
+      { // double quoted keys
+        begin: '"\\w[\\w :\\/.-]*":(?=[ \t]|$)'
+      },
+      { // single quoted keys
+        begin: '\'\\w[\\w :\\/.-]*\':(?=[ \t]|$)'
+      }
     ]
   };
 
-  var TEMPLATE_VARIABLES = {
+  const TEMPLATE_VARIABLES = {
     className: 'template-variable',
     variants: [
-      { begin: '{{', end: '}}' }, // jinja templates Ansible
-      { begin: '%{', end: '}' } // Ruby i18n
+      { // jinja templates Ansible
+        begin: /\{\{/,
+        end: /\}\}/
+      },
+      { // Ruby i18n
+        begin: /%\{/,
+        end: /\}/
+      }
     ]
   };
-  var STRING = {
+  const STRING = {
     className: 'string',
     relevance: 0,
     variants: [
-      { begin: /'/, end: /'/ },
-      { begin: /"/, end: /"/ },
-      { begin: /\S+/ }
+      {
+        begin: /'/,
+        end: /'/
+      },
+      {
+        begin: /"/,
+        end: /"/
+      },
+      {
+        begin: /\S+/
+      }
     ],
     contains: [
       hljs.BACKSLASH_ESCAPE,
@@ -49,51 +69,58 @@ function yaml(hljs) {
 
   // Strings inside of value containers (objects) can't contain braces,
   // brackets, or commas
-  var CONTAINER_STRING = hljs.inherit(STRING, {
+  const CONTAINER_STRING = hljs.inherit(STRING, {
     variants: [
-      { begin: /'/, end: /'/ },
-      { begin: /"/, end: /"/ },
-      { begin: /[^\s,{}[\]]+/ }
+      {
+        begin: /'/,
+        end: /'/
+      },
+      {
+        begin: /"/,
+        end: /"/
+      },
+      {
+        begin: /[^\s,{}[\]]+/
+      }
     ]
   });
 
-  var DATE_RE = '[0-9]{4}(-[0-9][0-9]){0,2}';
-  var TIME_RE = '([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?';
-  var FRACTION_RE = '(\\.[0-9]*)?';
-  var ZONE_RE = '([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?';
-  var TIMESTAMP = {
+  const DATE_RE = '[0-9]{4}(-[0-9][0-9]){0,2}';
+  const TIME_RE = '([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?';
+  const FRACTION_RE = '(\\.[0-9]*)?';
+  const ZONE_RE = '([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?';
+  const TIMESTAMP = {
     className: 'number',
     begin: '\\b' + DATE_RE + TIME_RE + FRACTION_RE + ZONE_RE + '\\b'
   };
 
-  var VALUE_CONTAINER = {
+  const VALUE_CONTAINER = {
     end: ',',
     endsWithParent: true,
     excludeEnd: true,
-    contains: [],
     keywords: LITERALS,
     relevance: 0
   };
-  var OBJECT = {
-    begin: '{',
-    end: '}',
-    contains: [VALUE_CONTAINER],
+  const OBJECT = {
+    begin: /\{/,
+    end: /\}/,
+    contains: [ VALUE_CONTAINER ],
     illegal: '\\n',
     relevance: 0
   };
-  var ARRAY = {
+  const ARRAY = {
     begin: '\\[',
     end: '\\]',
-    contains: [VALUE_CONTAINER],
+    contains: [ VALUE_CONTAINER ],
     illegal: '\\n',
     relevance: 0
   };
 
-  var MODES = [
+  const MODES = [
     KEY,
     {
       className: 'meta',
-      begin: '^---\s*$',
+      begin: '^---\\s*$',
       relevance: 10
     },
     { // multi line string
@@ -102,7 +129,7 @@ function yaml(hljs) {
       // Indentation of subsequent lines must be the same to
       // be considered part of the block
       className: 'string',
-      begin: '[\\|>]([0-9]?[+-])?[ ]*\\n( *)[\\S ]+\\n(\\2[\\S ]+\\n?)*'
+      begin: '[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*'
     },
     { // Ruby/Rails erb
       begin: '<%[%=-]?',
@@ -140,27 +167,30 @@ function yaml(hljs) {
     { // array listing
       className: 'bullet',
       // TODO: remove |$ hack when we have proper look-ahead support
-      begin: '\\-(?=[ ]|$)',
+      begin: '-(?=[ ]|$)',
       relevance: 0
     },
     hljs.HASH_COMMENT_MODE,
     {
       beginKeywords: LITERALS,
-      keywords: { literal: LITERALS }
+      keywords: {
+        literal: LITERALS
+      }
     },
     TIMESTAMP,
     // numbers are any valid C-style number that
     // sit isolated from other words
     {
       className: 'number',
-      begin: hljs.C_NUMBER_RE + '\\b'
+      begin: hljs.C_NUMBER_RE + '\\b',
+      relevance: 0
     },
     OBJECT,
     ARRAY,
     STRING
   ];
 
-  var VALUE_MODES = [...MODES];
+  const VALUE_MODES = [ ...MODES ];
   VALUE_MODES.pop();
   VALUE_MODES.push(CONTAINER_STRING);
   VALUE_CONTAINER.contains = VALUE_MODES;
@@ -168,7 +198,7 @@ function yaml(hljs) {
   return {
     name: 'YAML',
     case_insensitive: true,
-    aliases: ['yml', 'YAML'],
+    aliases: [ 'yml' ],
     contains: MODES
   };
 }
