@@ -121,7 +121,12 @@ def can_save_origin(origin_url: str, bypass_pending_review: bool = False) -> str
 
 # map visit type to scheduler task
 # TODO: do not hardcode the task name here (T1157)
-_visit_type_task = {"git": "load-git", "hg": "load-hg", "svn": "load-svn"}
+_visit_type_task = {
+    "git": "load-git",
+    "hg": "load-hg",
+    "svn": "load-svn",
+    "cvs": "load-cvs",
+}
 
 _visit_type_task_privileged = {
     "archives": "load-archive-files",
@@ -203,7 +208,9 @@ def _check_visit_type_savable(visit_type: str, privileged_user: bool = False) ->
         )
 
 
-_validate_url = URLValidator(schemes=["http", "https", "svn", "git"])
+_validate_url = URLValidator(
+    schemes=["http", "https", "svn", "git", "rsync", "pserver", "ssh"]
+)
 
 
 def _check_origin_url_valid(origin_url: str) -> None:
@@ -602,10 +609,16 @@ def update_save_origin_requests_from_queryset(
         task_ids.append(sor.loading_task_id)
     save_requests = []
     if task_ids:
-        tasks = scheduler().get_tasks(task_ids)
-        tasks = {task["id"]: task for task in tasks}
-        task_runs = scheduler().get_task_runs(tasks)
-        task_runs = {task_run["task"]: task_run for task_run in task_runs}
+        try:
+            tasks = scheduler().get_tasks(task_ids)
+            tasks = {task["id"]: task for task in tasks}
+            task_runs = scheduler().get_task_runs(tasks)
+            task_runs = {task_run["task"]: task_run for task_run in task_runs}
+        except Exception:
+            # allow to avoid mocking api GET responses for /origin/save endpoint when
+            # running cypress tests as scheduler is not available
+            tasks = {}
+            task_runs = {}
         for sor in requests_queryset:
             sr_dict = _update_save_request_info(
                 sor, tasks.get(sor.loading_task_id), task_runs.get(sor.loading_task_id),
@@ -717,26 +730,37 @@ def get_save_origin_task_info(
     except ObjectDoesNotExist:
         return {}
 
-    task = scheduler().get_tasks([save_request.loading_task_id])
+    task_info: Dict[str, Any] = {}
+    if save_request.note is not None:
+        task_info["note"] = save_request.note
+
+    try:
+        task = scheduler().get_tasks([save_request.loading_task_id])
+    except Exception:
+        # to avoid mocking GET responses of /save/task/info/ endpoint when running
+        # cypress tests as scheduler is not available in that case
+        task = None
+
     task = task[0] if task else None
     if task is None:
-        return {}
+        return task_info
 
     task_run = scheduler().get_task_runs([task["id"]])
     task_run = task_run[0] if task_run else None
     if task_run is None:
-        return {}
-    task_run["type"] = task["type"]
-    task_run["arguments"] = task["arguments"]
-    task_run["id"] = task_run["task"]
-    del task_run["task"]
-    del task_run["metadata"]
-    # Enrich the task run with the loading visit status
-    task_run["visit_status"] = save_request.visit_status
+        return task_info
+    task_info.update(task_run)
+    task_info["type"] = task["type"]
+    task_info["arguments"] = task["arguments"]
+    task_info["id"] = task_run["task"]
+    del task_info["task"]
+    del task_info["metadata"]
+    # Enrich the task info with the loading visit status
+    task_info["visit_status"] = save_request.visit_status
 
     es_workers_index_url = get_config()["es_workers_index_url"]
     if not es_workers_index_url:
-        return task_run
+        return task_info
     es_workers_index_url += "/_search"
 
     if save_request.visit_date:
@@ -780,17 +804,17 @@ def get_save_origin_task_info(
             task_run_info = results["hits"]["hits"][-1]["_source"]
             if "swh_logging_args_runtime" in task_run_info:
                 duration = task_run_info["swh_logging_args_runtime"]
-                task_run["duration"] = duration
+                task_info["duration"] = duration
             if "message" in task_run_info:
-                task_run["message"] = task_run_info["message"]
+                task_info["message"] = task_run_info["message"]
             if "swh_logging_args_name" in task_run_info:
-                task_run["name"] = task_run_info["swh_logging_args_name"]
+                task_info["name"] = task_run_info["swh_logging_args_name"]
             elif "swh_task_name" in task_run_info:
-                task_run["name"] = task_run_info["swh_task_name"]
+                task_info["name"] = task_run_info["swh_task_name"]
             if "hostname" in task_run_info:
-                task_run["worker"] = task_run_info["hostname"]
+                task_info["worker"] = task_run_info["hostname"]
             elif "host" in task_run_info:
-                task_run["worker"] = task_run_info["host"]
+                task_info["worker"] = task_run_info["host"]
     except Exception as exc:
         logger.warning("Request to Elasticsearch failed\n%s", exc)
         sentry_sdk.capture_exception(exc)
@@ -798,19 +822,19 @@ def get_save_origin_task_info(
     if not full_info:
         for field in ("id", "backend_id", "worker"):
             # remove some staff only fields
-            task_run.pop(field, None)
+            task_info.pop(field, None)
         if "message" in task_run and "Loading failure" in task_run["message"]:
             # hide traceback for non staff users, only display exception
-            message_lines = task_run["message"].split("\n")
+            message_lines = task_info["message"].split("\n")
             message = ""
             for line in message_lines:
                 if line.startswith("Traceback"):
                     break
                 message += f"{line}\n"
             message += message_lines[-1]
-            task_run["message"] = message
+            task_info["message"] = message
 
-    return task_run
+    return task_info
 
 
 SUBMITTED_SAVE_REQUESTS_METRIC = "swh_web_submitted_save_requests"
