@@ -7,6 +7,7 @@ from datetime import datetime, timezone
 import os
 import re
 from typing import Any, Dict, List, Optional
+import urllib.parse
 
 from bs4 import BeautifulSoup
 from docutils.core import publish_parts
@@ -21,6 +22,8 @@ from requests.auth import HTTPBasicAuth
 
 from django.core.cache import cache
 from django.http import HttpRequest, QueryDict
+from django.shortcuts import redirect
+from django.urls import resolve
 from django.urls import reverse as django_reverse
 
 from swh.web.auth.utils import ADMIN_LIST_DEPOSIT_PERMISSION
@@ -370,10 +373,10 @@ def prettify_html(html: str) -> str:
 def _deposits_list_url(
     deposits_list_base_url: str, page_size: int, username: Optional[str]
 ) -> str:
-    deposits_list_url = f"{deposits_list_base_url}?page_size={page_size}"
+    params = {"page_size": str(page_size)}
     if username is not None:
-        deposits_list_url += f"&username={username}"
-    return deposits_list_url
+        params["username"] = username
+    return f"{deposits_list_base_url}?{urllib.parse.urlencode(params)}"
 
 
 def get_deposits_list(username: Optional[str] = None) -> List[Dict[str, Any]]:
@@ -414,3 +417,13 @@ def origin_visit_types() -> List[str]:
         return sorted(search().visit_types_count().keys())
     except Exception:
         return []
+
+
+def redirect_to_new_route(request, new_route, permanent=True):
+    """Redirect a request to another route with url args and query parameters
+    eg: /origin/<url:url-val>/log?path=test can be redirected as
+    /log?url=<url-val>&path=test. This can be used to deprecate routes
+    """
+    request_path = resolve(request.path_info)
+    args = {**request_path.kwargs, **request.GET.dict()}
+    return redirect(reverse(new_route, query_params=args), permanent=permanent,)
