@@ -1,22 +1,18 @@
-# Copyright (C) 2020  The Software Heritage developers
+# Copyright (C) 2021  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 import hashlib
-import json
 import textwrap
 
-from hypothesis import given
-
 from django.http.response import StreamingHttpResponse
 
 from swh.model.hashutil import hash_to_bytes
-from swh.model.identifiers import ExtendedObjectType, ExtendedSWHID
+from swh.model.swhids import ExtendedObjectType, ExtendedSWHID
 from swh.web.api.views.graph import API_GRAPH_PERM
 from swh.web.common.utils import reverse
 from swh.web.config import SWH_WEB_INTERNAL_SERVER_NAME, get_config
-from swh.web.tests.strategies import origin
 from swh.web.tests.utils import check_http_get_response
 
 
@@ -129,7 +125,7 @@ def test_graph_json_response(api_client, keycloak_oidc, requests_mock):
 
     resp = check_http_get_response(api_client, url, status_code=200)
     assert resp.content_type == "application/json"
-    assert resp.content == json.dumps(_response_json).encode()
+    assert resp.data == _response_json
 
 
 def test_graph_ndjson_response(api_client, keycloak_oidc, requests_mock):
@@ -165,7 +161,6 @@ def test_graph_ndjson_response(api_client, keycloak_oidc, requests_mock):
     assert b"".join(resp.streaming_content) == response_ndjson.encode()
 
 
-@given(origin())
 def test_graph_response_resolve_origins(
     archive_data, api_client, keycloak_oidc, requests_mock, origin
 ):
@@ -258,4 +253,18 @@ def test_graph_response_resolve_origins_nothing_to_do(
 
     resp = check_http_get_response(api_client, url, status_code=200)
     assert resp.content_type == "application/json"
-    assert resp.content == json.dumps(_response_json).encode()
+    assert resp.data == _response_json
+
+
+def test_graph_response_invalid_accept_header(api_client):
+    url = reverse(
+        "api-1-graph",
+        url_args={"graph_query": "stats"},
+        query_params={"resolve_origins": "true"},
+    )
+
+    resp = api_client.get(url, HTTP_ACCEPT="text/html")
+    assert resp.status_code == 406
+    assert resp.content_type == "application/json"
+    assert resp.data["exception"] == "NotAcceptable"
+    assert resp.data["reason"] == "Could not satisfy the request Accept header."
